pub struct DecayWindow {
pub stale_after_ticks: u64,
pub next_refresh_within_ticks: u64,
}Expand description
Per-engine staleness and refresh window configuration.
stale_after_ticks is the number of ticks an observation may age before it
is dropped. next_refresh_within_ticks is the upper bound on how soon the
next engine tick should refresh derived tables.
Fields
stale_after_ticks: u64next_refresh_within_ticks: u64Implementations